<?php
/**
 * Gwangi_Merlin Class
 *
 * @author  Themosaurus
 * @since   1.0.0
 * @package gwangi
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Gwangi_Merlin' ) ) :
	/**
	 * The Gwangi Merlin Activation class
	 */
	class Gwangi_Merlin extends Themosaurus_Merlin {

		/**
		 * Get the demo setups arguments that will be sent to Merlin WP
		 *
		 * @return array
		 */
		protected function get_demo_setups_args() {
			return apply_filters( 'gwangi_demo_setups_args', array(
				'classic'   => array(
					'import_file_name'           => 'Gwangi Classic Demo',
					'import_file_url'            => 'http://files.themosaurus.com/gwangi/demos/classic/demo-content.xml',
					'import_widget_file_url'     => 'http://files.themosaurus.com/gwangi/demos/classic/widgets.wie',
					'import_customizer_file_url' => 'http://files.themosaurus.com/gwangi/demos/classic/customizer.dat',
					'import_file_screenshot'     => get_template_directory_uri() . '/assets/images/screenshots/classic.png',
					'import_notice'              => esc_html__( 'Visit doc.themosaurus.com to get the full documentation for the theme', 'gwangi' ),
					'before_import_method'       => 'before_import',
					'after_import_method'        => 'after_import_classic',
					'preview_url'                => 'http://classic.gwangi-theme.com/',
					'tgmpa'                      => array(
						array(
							'name'     => 'Author Avatars List',
							'slug'     => 'author-avatars',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress',
							'slug'     => 'buddypress',
							'required' => true,
						),
						array(
							'name'     => 'bbPress',
							'slug'     => 'bbpress',
							'required' => false,
						),
						array(
							'name'     => 'BP Better Messages',
							'slug'     => 'bp-better-messages',
							'required' => false,
						),
						array(
							'name'     => 'BP Profile Search',
							'slug'     => 'bp-profile-search',
							'required' => false,
						),
						array(
							'name'     => 'Menu Image',
							'slug'     => 'menu-image',
							'required' => false,
						),
						array(
							'name'     => 'rtMedia for WordPress, BuddyPress and bbPress',
							'slug'     => 'buddypress-media',
							'required' => false,
						),
						array(
							'name'     => 'Verified Member for BuddyPress',
							'slug'     => 'bp-verified-member',
							'required' => false,
						),
						array(
							'name'         => 'Grimlock for BuddyPress',
							'slug'         => 'grimlock-buddypress',
							'source'       => 'http://files.themosaurus.com/grimlock-buddypress/grimlock-buddypress.zip',
							'required'     => true,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock Isotope',
							'slug'         => 'grimlock-isotope',
							'source'       => 'http://files.themosaurus.com/grimlock-isotope/grimlock-isotope.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for Author Avatars List',
							'slug'         => 'grimlock-author-avatars',
							'source'       => 'http://files.themosaurus.com/grimlock-author-avatars/grimlock-author-avatars.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for bbPress',
							'slug'         => 'grimlock-bbpress',
							'source'       => 'http://files.themosaurus.com/grimlock-bbpress/grimlock-bbpress.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
					),
				),
				'community' => array(
					'import_file_name'           => 'Gwangi Community Demo',
					'import_file_url'            => 'http://files.themosaurus.com/gwangi/demos/community/demo-content.xml',
					'import_widget_file_url'     => 'http://files.themosaurus.com/gwangi/demos/community/widgets.wie',
					'import_customizer_file_url' => 'http://files.themosaurus.com/gwangi/demos/community/customizer.dat',
					'import_file_screenshot'     => get_template_directory_uri() . '/assets/images/screenshots/community.png',
					'import_notice'              => esc_html__( 'Visit doc.themosaurus.com to get the full documentation for the theme', 'gwangi' ),
					'before_import_method'       => 'before_import',
					'after_import_method'        => 'after_import_community',
					'preview_url'                => 'http://community.gwangi-theme.com/',
					'tgmpa'                      => array(
						array(
							'name'     => 'Author Avatars List',
							'slug'     => 'author-avatars',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress',
							'slug'     => 'buddypress',
							'required' => true,
						),
						array(
							'name'     => 'bbPress',
							'slug'     => 'bbpress',
							'required' => false,
						),
						array(
							'name'     => 'BP Better Messages',
							'slug'     => 'bp-better-messages',
							'required' => false,
						),
						array(
							'name'     => 'BP Profile Search',
							'slug'     => 'bp-profile-search',
							'required' => false,
						),
						array(
							'name'     => 'Menu Image',
							'slug'     => 'menu-image',
							'required' => false,
						),
						array(
							'name'     => 'rtMedia for WordPress, BuddyPress and bbPress',
							'slug'     => 'buddypress-media',
							'required' => false,
						),
						array(
							'name'     => 'Verified Member for BuddyPress',
							'slug'     => 'bp-verified-member',
							'required' => false,
						),
						array(
							'name'         => 'Grimlock for BuddyPress',
							'slug'         => 'grimlock-buddypress',
							'source'       => 'http://files.themosaurus.com/grimlock-buddypress/grimlock-buddypress.zip',
							'required'     => true,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock Isotope',
							'slug'         => 'grimlock-isotope',
							'source'       => 'http://files.themosaurus.com/grimlock-isotope/grimlock-isotope.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for Author Avatars List',
							'slug'         => 'grimlock-author-avatars',
							'source'       => 'http://files.themosaurus.com/grimlock-author-avatars/grimlock-author-avatars.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for bbPress',
							'slug'         => 'grimlock-bbpress',
							'source'       => 'http://files.themosaurus.com/grimlock-bbpress/grimlock-bbpress.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
					),
				),
				'dating'    => array(
					'import_file_name'           => 'Gwangi Dating Demo',
					/* translators: 1: Opening <a> tag 2: Closing <a> tag 3: Opening <strong> tag 4: Closing <strong> tag */
					'import_file_url'            => 'http://files.themosaurus.com/gwangi/demos/dating/demo-content.xml',
					'import_widget_file_url'     => 'http://files.themosaurus.com/gwangi/demos/dating/widgets.wie',
					'import_customizer_file_url' => 'http://files.themosaurus.com/gwangi/demos/dating/customizer.dat',
					'import_file_screenshot'     => get_template_directory_uri() . '/assets/images/screenshots/dating.png',
					'import_notice'              => esc_html__( 'Visit doc.themosaurus.com to get the full documentation for the theme', 'gwangi' ),
					'before_import_method'       => 'before_import',
					'after_import_method'        => 'after_import_dating',
					'preview_url'                => 'http://dating.gwangi-theme.com/',
					'tgmpa'                      => array(
						array(
							'name'     => 'Author Avatars List',
							'slug'     => 'author-avatars',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress',
							'slug'     => 'buddypress',
							'required' => true,
						),
						array(
							'name'     => 'bbPress',
							'slug'     => 'bbpress',
							'required' => false,
						),
						array(
							'name'     => 'BP Better Messages',
							'slug'     => 'bp-better-messages',
							'required' => false,
						),
						array(
							'name'     => 'BP Profile Search',
							'slug'     => 'bp-profile-search',
							'required' => false,
						),
						array(
							'name'     => 'Menu Image',
							'slug'     => 'menu-image',
							'required' => false,
						),
						array(
							'name'     => 'rtMedia for WordPress, BuddyPress and bbPress',
							'slug'     => 'buddypress-media',
							'required' => false,
						),
						array(
							'name'     => 'Verified Member for BuddyPress',
							'slug'     => 'bp-verified-member',
							'required' => false,
						),
						array(
							'name'         => 'Grimlock for BuddyPress',
							'slug'         => 'grimlock-buddypress',
							'source'       => 'http://files.themosaurus.com/grimlock-buddypress/grimlock-buddypress.zip',
							'required'     => true,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock Isotope',
							'slug'         => 'grimlock-isotope',
							'source'       => 'http://files.themosaurus.com/grimlock-isotope/grimlock-isotope.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for Author Avatars List',
							'slug'         => 'grimlock-author-avatars',
							'source'       => 'http://files.themosaurus.com/grimlock-author-avatars/grimlock-author-avatars.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for bbPress',
							'slug'         => 'grimlock-bbpress',
							'source'       => 'http://files.themosaurus.com/grimlock-bbpress/grimlock-bbpress.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
					),
				),
				'shop'      => array(
					'import_file_name'           => 'Gwangi Shop Demo',
					'import_file_url'            => 'http://files.themosaurus.com/gwangi/demos/shop/demo-content.xml',
					'import_widget_file_url'     => 'http://files.themosaurus.com/gwangi/demos/shop/widgets.wie',
					'import_customizer_file_url' => 'http://files.themosaurus.com/gwangi/demos/shop/customizer.dat',
					'import_file_screenshot'     => get_template_directory_uri() . '/assets/images/screenshots/shop.png',
					'import_notice'              => esc_html__( 'Visit doc.themosaurus.com to get the full documentation for the theme', 'gwangi' ),
					'after_import_method'        => 'after_import_shop',
					'preview_url'                => 'http://shop.gwangi-theme.com/',
					'tgmpa'                      => array(
						array(
							'name'     => 'Menu Image',
							'slug'     => 'menu-image',
							'required' => false,
						),
						array(
							'name'     => 'WC Secondary Product Thumbnail',
							'slug'     => 'wc-secondary-product-thumbnail',
							'required' => false,
						),
						array(
							'name'     => 'WooCommerce',
							'slug'     => 'woocommerce',
							'required' => false,
						),
						array(
							'name'         => 'WooCommerce Quantity Increment',
							'slug'         => 'woocommerce-quantity-increment',
							'source'       => 'https://github.com/woocommerce/WooCommerce-Quantity-Increment/archive/master.zip',
							'required'     => false,
							'external_url' => 'https://github.com/woocommerce/WooCommerce-Quantity-Increment/',
						),
						array(
							'name'     => 'YITH Infinite Scrolling',
							'slug'     => 'yith-infinite-scrolling',
							'required' => false,
						),
						array(
							'name'     => 'YITH WooCommerce Ajax Search',
							'slug'     => 'yith-woocommerce-ajax-search',
							'required' => false,
						),
						array(
							'name'     => 'YITH WooCommerce Quick View',
							'slug'     => 'yith-woocommerce-quick-view',
							'required' => false,
						),
						array(
							'name'     => 'YITH WooCommerce Wishlist',
							'slug'     => 'yith-woocommerce-wishlist',
							'required' => false,
						),
						array(
							'name'         => 'Grimlock for WooCommerce',
							'slug'         => 'grimlock-woocommerce',
							'source'       => 'http://files.themosaurus.com/grimlock-woocommerce/grimlock-woocommerce.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock Isotope',
							'slug'         => 'grimlock-isotope',
							'source'       => 'http://files.themosaurus.com/grimlock-isotope/grimlock-isotope.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
					),
				),
				'youzify'   => array(
					'import_file_name'           => 'Gwangi Youzify Demo',
					'import_file_url'            => 'http://files.themosaurus.com/gwangi/demos/youzify/demo-content.xml',
					'import_widget_file_url'     => 'http://files.themosaurus.com/gwangi/demos/youzify/widgets.wie',
					'import_customizer_file_url' => 'http://files.themosaurus.com/gwangi/demos/youzify/customizer.dat',
					'import_file_screenshot'     => get_template_directory_uri() . '/assets/images/screenshots/youzify.png',
					'import_notice'              => esc_html__( 'Visit doc.themosaurus.com to get the full documentation for the theme', 'gwangi' ),
					'before_import_method'       => 'before_import',
					'after_import_method'        => 'after_import_youzify',
					'preview_url'                => 'http://youzify.gwangi-theme.com/',
					'tgmpa'                      => array(
						array(
							'name'     => 'Author Avatars List',
							'slug'     => 'author-avatars',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress',
							'slug'     => 'buddypress',
							'required' => true,
						),
						array(
							'name'     => 'bbPress',
							'slug'     => 'bbpress',
							'required' => false,
						),
						array(
							'name'     => 'BP Better Messages',
							'slug'     => 'bp-better-messages',
							'required' => false,
						),
						array(
							'name'     => 'BP Profile Search',
							'slug'     => 'bp-profile-search',
							'required' => false,
						),
						array(
							'name'     => 'Menu Image',
							'slug'     => 'menu-image',
							'required' => false,
						),
						array(
							'name'     => 'rtMedia for WordPress, BuddyPress and bbPress',
							'slug'     => 'buddypress-media',
							'required' => false,
						),
						array(
							'name'     => 'Youzify',
							'slug'     => 'youzify',
							'required' => false,
						),
						array(
							'name'         => 'Grimlock for BuddyPress',
							'slug'         => 'grimlock-buddypress',
							'source'       => 'http://files.themosaurus.com/grimlock-buddypress/grimlock-buddypress.zip',
							'required'     => true,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock Isotope',
							'slug'         => 'grimlock-isotope',
							'source'       => 'http://files.themosaurus.com/grimlock-isotope/grimlock-isotope.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for Author Avatars List',
							'slug'         => 'grimlock-author-avatars',
							'source'       => 'http://files.themosaurus.com/grimlock-author-avatars/grimlock-author-avatars.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for bbPress',
							'slug'         => 'grimlock-bbpress',
							'source'       => 'http://files.themosaurus.com/grimlock-bbpress/grimlock-bbpress.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
					),
				),
				'spiritual' => array(
					'import_file_name'           => 'Gwangi Spiritual Demo',
					'import_file_url'            => 'http://files.themosaurus.com/gwangi/demos/spiritual/demo-content.xml',
					'import_widget_file_url'     => 'http://files.themosaurus.com/gwangi/demos/spiritual/widgets.wie',
					'import_customizer_file_url' => 'http://files.themosaurus.com/gwangi/demos/spiritual/customizer.dat',
					'import_file_screenshot'     => get_template_directory_uri() . '/assets/images/screenshots/spiritual.png',
					'import_notice'              => esc_html__( 'Visit doc.themosaurus.com to get the full documentation for the theme', 'gwangi' ),
					'before_import_method'       => 'before_import',
					'after_import_method'        => 'after_import_spiritual',
					'preview_url'                => 'http://spiritual.gwangi-theme.com/',
					'tgmpa'                      => array(
						array(
							'name'     => 'Author Avatars List',
							'slug'     => 'author-avatars',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress',
							'slug'     => 'buddypress',
							'required' => true,
						),
						array(
							'name'     => 'bbPress',
							'slug'     => 'bbpress',
							'required' => false,
						),
						array(
							'name'     => 'BP Better Messages',
							'slug'     => 'bp-better-messages',
							'required' => false,
						),
						array(
							'name'     => 'BP Profile Search',
							'slug'     => 'bp-profile-search',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress Global Search',
							'slug'     => 'buddypress-global-search',
							'required' => false,
						),
						array(
							'name'     => 'Menu Image',
							'slug'     => 'menu-image',
							'required' => false,
						),
						array(
							'name'     => 'rtMedia for WordPress, BuddyPress and bbPress',
							'slug'     => 'buddypress-media',
							'required' => false,
						),
						array(
							'name'     => 'Verified Member for BuddyPress',
							'slug'     => 'bp-verified-member',
							'required' => false,
						),
						array(
							'name'         => 'Grimlock for BuddyPress',
							'slug'         => 'grimlock-buddypress',
							'source'       => 'http://files.themosaurus.com/grimlock-buddypress/grimlock-buddypress.zip',
							'required'     => true,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock Isotope',
							'slug'         => 'grimlock-isotope',
							'source'       => 'http://files.themosaurus.com/grimlock-isotope/grimlock-isotope.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for Author Avatars List',
							'slug'         => 'grimlock-author-avatars',
							'source'       => 'http://files.themosaurus.com/grimlock-author-avatars/grimlock-author-avatars.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for bbPress',
							'slug'         => 'grimlock-bbpress',
							'source'       => 'http://files.themosaurus.com/grimlock-bbpress/grimlock-bbpress.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
					),
				),
				'mentor'    => array(
					'import_file_name'           => 'Gwangi Mentor Demo',
					'import_file_url'            => 'http://files.themosaurus.com/gwangi/demos/mentor/demo-content.xml',
					'import_widget_file_url'     => 'http://files.themosaurus.com/gwangi/demos/mentor/widgets.wie',
					'import_customizer_file_url' => 'http://files.themosaurus.com/gwangi/demos/mentor/customizer.dat',
					'import_file_screenshot'     => get_template_directory_uri() . '/assets/images/screenshots/mentor.png',
					'import_notice'              => esc_html__( 'Visit doc.themosaurus.com to get the full documentation for the theme', 'gwangi' ),
					'before_import_method'       => 'before_import',
					'after_import_method'        => 'after_import_mentor',
					'preview_url'                => 'http://mentor.gwangi-theme.com/',
					'tgmpa'                      => array(
						array(
							'name'     => 'Author Avatars List',
							'slug'     => 'author-avatars',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress',
							'slug'     => 'buddypress',
							'required' => true,
						),
						array(
							'name'     => 'bbPress',
							'slug'     => 'bbpress',
							'required' => false,
						),
						array(
							'name'     => 'BP Better Messages',
							'slug'     => 'bp-better-messages',
							'required' => false,
						),
						array(
							'name'     => 'BP Profile Search',
							'slug'     => 'bp-profile-search',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress Member Reviews',
							'slug'     => 'bp-user-profile-reviews',
							'required' => false,
						),
						array(
							'name'     => 'Menu Image',
							'slug'     => 'menu-image',
							'required' => false,
						),
						array(
							'name'     => 'rtMedia for WordPress, BuddyPress and bbPress',
							'slug'     => 'buddypress-media',
							'required' => false,
						),
						array(
							'name'     => 'Verified Member for BuddyPress',
							'slug'     => 'bp-verified-member',
							'required' => false,
						),
						array(
							'name'         => 'Grimlock for BuddyPress',
							'slug'         => 'grimlock-buddypress',
							'source'       => 'http://files.themosaurus.com/grimlock-buddypress/grimlock-buddypress.zip',
							'required'     => true,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock Isotope',
							'slug'         => 'grimlock-isotope',
							'source'       => 'http://files.themosaurus.com/grimlock-isotope/grimlock-isotope.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for Author Avatars List',
							'slug'         => 'grimlock-author-avatars',
							'source'       => 'http://files.themosaurus.com/grimlock-author-avatars/grimlock-author-avatars.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for bbPress',
							'slug'         => 'grimlock-bbpress',
							'source'       => 'http://files.themosaurus.com/grimlock-bbpress/grimlock-bbpress.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
					),
				),
				'nightlife' => array(
					'import_file_name'           => 'Gwangi Nightlife Demo',
					'import_file_url'            => 'http://files.themosaurus.com/gwangi/demos/nightlife/demo-content.xml',
					'import_widget_file_url'     => 'http://files.themosaurus.com/gwangi/demos/nightlife/widgets.wie',
					'import_customizer_file_url' => 'http://files.themosaurus.com/gwangi/demos/nightlife/customizer.dat',
					'import_file_screenshot'     => get_template_directory_uri() . '/assets/images/screenshots/nightlife.png',
					'import_notice'              => esc_html__( 'Visit doc.themosaurus.com to get the full documentation for the theme', 'gwangi' ),
					'before_import_method'       => 'before_import',
					'after_import_method'        => 'after_import_nightlife',
					'preview_url'                => 'http://nightlife.gwangi-theme.com/',
					'tgmpa'                      => array(
						array(
							'name'     => 'Author Avatars List',
							'slug'     => 'author-avatars',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress',
							'slug'     => 'buddypress',
							'required' => true,
						),
						array(
							'name'     => 'bbPress',
							'slug'     => 'bbpress',
							'required' => false,
						),
						array(
							'name'     => 'BP Better Messages',
							'slug'     => 'bp-better-messages',
							'required' => false,
						),
						array(
							'name'     => 'BP Profile Search',
							'slug'     => 'bp-profile-search',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress Global Search',
							'slug'     => 'buddypress-global-search',
							'required' => false,
						),
						array(
							'name'     => 'Menu Image',
							'slug'     => 'menu-image',
							'required' => false,
						),
						array(
							'name'     => 'rtMedia for WordPress, BuddyPress and bbPress',
							'slug'     => 'buddypress-media',
							'required' => false,
						),
						array(
							'name'     => 'The Events Calendar',
							'slug'     => 'the-events-calendar',
							'required' => false,
						),
						array(
							'name'     => 'Verified Member for BuddyPress',
							'slug'     => 'bp-verified-member',
							'required' => false,
						),
						array(
							'name'         => 'Grimlock for BuddyPress',
							'slug'         => 'grimlock-buddypress',
							'source'       => 'http://files.themosaurus.com/grimlock-buddypress/grimlock-buddypress.zip',
							'required'     => true,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock Isotope',
							'slug'         => 'grimlock-isotope',
							'source'       => 'http://files.themosaurus.com/grimlock-isotope/grimlock-isotope.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for Author Avatars List',
							'slug'         => 'grimlock-author-avatars',
							'source'       => 'http://files.themosaurus.com/grimlock-author-avatars/grimlock-author-avatars.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for The Events Calendar',
							'slug'         => 'grimlock-the-events-calendar',
							'source'       => 'http://files.themosaurus.com/grimlock-the-events-calendar/grimlock-the-events-calendar.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for bbPress',
							'slug'         => 'grimlock-bbpress',
							'source'       => 'http://files.themosaurus.com/grimlock-bbpress/grimlock-bbpress.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
					),
				),
				'learn'     => array(
					'import_file_name'           => 'Gwangi Learn Demo',
					/* translators: 1: Opening <a> tag 2: Closing <a> tag 3: Opening <strong> tag 4: Closing <strong> tag */
					'import_file_warning'        => '<strong>' . esc_html__( 'Heads up!', 'gwangi' ) . '</strong><p>' . sprintf( esc_html__( 'This demo is based on the %1$sLearnDash%2$s plugin. This is a paid plugin and it is not included with Gwangi. We recommend that you manually install it %3$sbefore%4$s importing this demo.', 'gwangi' ), '<a target="_blank" href="https://www.learndash.com/">', '</a>', '<strong>', '</strong>' ) . '</p>',
					'import_file_url'            => 'http://files.themosaurus.com/gwangi/demos/learn/demo-content.xml',
					'import_widget_file_url'     => 'http://files.themosaurus.com/gwangi/demos/learn/widgets.wie',
					'import_customizer_file_url' => 'http://files.themosaurus.com/gwangi/demos/learn/customizer.dat',
					'import_file_screenshot'     => get_template_directory_uri() . '/assets/images/screenshots/learn.png',
					'import_notice'              => esc_html__( 'Visit doc.themosaurus.com to get the full documentation for the theme', 'gwangi' ),
					'before_import_method'       => 'before_import',
					'after_import_method'        => 'after_import_learn',
					'import_finished_warning'    => '<strong>' . esc_html__( 'Heads up!', 'gwangi' ) . '</strong><p>' . sprintf( esc_html__( 'To complete this demo setup, don\'t forget to install the %1$sLearnDash%2$s plugin if you haven\'t already.', 'gwangi' ), '<a href="https://www.learndash.com/" target="_blank">', '</a>' ) . '</p>',
					'preview_url'                => 'http://learn.gwangi-theme.com/',
					'tgmpa'                      => array(
						array(
							'name'     => 'Author Avatars List',
							'slug'     => 'author-avatars',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress',
							'slug'     => 'buddypress',
							'required' => true,
						),
						array(
							'name'     => 'bbPress',
							'slug'     => 'bbpress',
							'required' => false,
						),
						array(
							'name'     => 'BP Better Messages',
							'slug'     => 'bp-better-messages',
							'required' => false,
						),
						array(
							'name'     => 'BP Profile Search',
							'slug'     => 'bp-profile-search',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress for LearnDash',
							'slug'     => 'buddypress-learndash',
							'required' => false,
						),
						array(
							'name'     => 'BuddyPress Global Search',
							'slug'     => 'buddypress-global-search',
							'required' => false,
						),
						array(
							'name'     => 'rtMedia for WordPress, BuddyPress and bbPress',
							'slug'     => 'buddypress-media',
							'required' => false,
						),
						array(
							'name'     => 'Verified Member for BuddyPress',
							'slug'     => 'bp-verified-member',
							'required' => false,
						),
						array(
							'name'         => 'Grimlock for BuddyPress',
							'slug'         => 'grimlock-buddypress',
							'source'       => 'http://files.themosaurus.com/grimlock-buddypress/grimlock-buddypress.zip',
							'required'     => true,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock Isotope',
							'slug'         => 'grimlock-isotope',
							'source'       => 'http://files.themosaurus.com/grimlock-isotope/grimlock-isotope.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for Author Avatars List',
							'slug'         => 'grimlock-author-avatars',
							'source'       => 'http://files.themosaurus.com/grimlock-author-avatars/grimlock-author-avatars.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
						array(
							'name'         => 'Grimlock for bbPress',
							'slug'         => 'grimlock-bbpress',
							'source'       => 'http://files.themosaurus.com/grimlock-bbpress/grimlock-bbpress.zip',
							'required'     => false,
							'external_url' => 'https://www.themosaurus.com/',
						),
					),
				),
			) );
		}

		/**
		 * Before import logic
		 */
		public function before_import() {
			$this->setup_bp_components( array(
				'groups'   => true,
				'friends'  => true,
				'messages' => true,
			) );
		}

		/**
		 * After import logic for the Classic demo
		 */
		public function after_import_classic() {
			$this->convert_menu_items_relative_urls_to_absolute_urls();
			$this->delete_duplicate_pages();

			$this->assign_menus_to_locations( array(
				'primary'         => 'Primary',
				'user_logged_in'  => 'User - Logged In',
				'user_logged_out' => 'User - Logged Out',
			) );

			$this->fix_menu_items_hierarchy( 'Primary', array(
				'Home' => array(
					'Home 1',
					'Home 2',
				),
				'Community' => array(
					'menu image',
					'Members' => array(
						'Members Directory',
						'Swipe Members' => array(
							'All Members',
							'Only New York',
						),
						'Member Profile',
					),
					'Groups' => array(
						'Groups Directory',
						'Group Profile',
						'+Create Group',
					),
					'Others' => array(
						'Social Wall',
						'Forums',
						'Register',
						'Log In',
					),
				),
				'Pages' => array(
					'Members Lists',
					'Groups Lists',
					'About us',
					'Coming Soon',
				),
				'More' => array(
					'E Learning',
					'Shop',
					'Coaching',
					'Social Wall',
				),
			) );

			$this->delete_menu_items( 'Primary', array(
				untrailingslashit( home_url( '/members/elia/' ) ),
				untrailingslashit( home_url( '/groups/tatoo' ) ),
				'http://shop.gwangi-theme.com',
			), 'url' );

			$this->fix_menu_items_titles( 'Features - Homepage', array(
				'Talk to Real People'      => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-love-on"></i><span class="h5 d-block">Talk to Real People</span></span>',
				'Smooth & Simple Features' => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-smile"></i><span class="h5 d-block">Smooth & Simple Features</span></span>',
				'Your Data are Safe'       => '<span class="icon-wrapper"><i class="fa fa-lock"></i><span class="h5 d-block">Your Data are Safe</span></span>',
			) );

			$this->fix_menu_items_titles( 'Social', array(
				'https://www.instagram.com/' => '<i class="fa fa-instagram"></i>',
				'https://twitter.com/'       => '<i class="fa fa-twitter"></i>',
				'https://www.facebook.com/'  => '<i class="fa fa-facebook-official"></i>',
				'https://www.youtube.com/'   => '<i class="fa fa-youtube-play"></i>',
				'https://www.snapchat.com/'  => '<i class="fa fa-snapchat-square"></i>',
			), 'url' );

			$this->set_custom_logo( 'logo-classic-inverted' );

			if ( class_exists( 'BuddyPress' ) ) {
				$this->enable_user_registrations();

				// Generate profile fields in the "Base" tab
				$this->generate_base_xprofile_fields();

				// Fix members directory search forms
				$directory_search_fields = array(
					'Name',
					'Passion',
					'Birthdate',
					'Gender',
					'Country',
					'City',
					'any',
				);
				$this->fix_bps_form( 'Search directory', $directory_search_fields, 'Members' );
				$this->fix_bps_form( 'Search Directory Sidebar Left', $directory_search_fields, 'Members Sidebar Left' );
				$this->fix_bps_form( 'Search Directory Sidebar Right', $directory_search_fields, 'Members Sidebar Right' );

				// Get ids of component pages (directories pages, register page, etc...)
				$directory_pages = bp_get_option( 'bp-pages' );

				// Adjust Interests menu items
				$interests_menu        = get_term_by( 'name', 'Interests', 'nav_menu' );
				$interests_menu_items  = wp_get_nav_menu_items( $interests_menu );
				$directory_search_form = get_page_by_title( 'Search directory', 'OBJECT', 'bps_form' );
				if ( ! empty( $directory_search_form ) ) {
					foreach ( $interests_menu_items as $menu_item ) {
						$menu_item->url = esc_url( add_query_arg( array(
							'field_' . xprofile_get_field_id_from_name( 'Passion' ) => urlencode( str_replace( ' ', '+', $menu_item->title ) ),
							'bps_form' => $directory_search_form->ID,
						), get_permalink( $directory_pages['members'] ) ) );

						$this->update_menu_item( $interests_menu->term_id, $menu_item );
					}
				}
			}
		}

		/**
		 * After import logic for the Community demo
		 */
		public function after_import_community() {
			$this->convert_menu_items_relative_urls_to_absolute_urls();
			$this->delete_duplicate_pages();

			$this->assign_menus_to_locations( array(
				'primary'         => 'Primary',
				'user_logged_in'  => 'User - Logged In',
				'user_logged_out' => 'User - Logged Out',
			) );

			$this->fix_menu_items_hierarchy( 'Primary', array(
				'Home' => array(
					'Home 1',
					'Home 2',
				),
				'Community' => array(
					'menu image',
					'Members' => array(
						'Members Directory',
						'Swipe Members' => array(
							'All Members',
							'Only New York',
						),
						'Member Profile',
					),
					'Groups' => array(
						'Groups Directory',
						'Group Profile',
						'+Create Group',
					),
					'Others' => array(
						'Social Wall',
						'Forums',
						'Register',
						'Log In',
					),
				),
				'Pages' => array(
					'Members Lists',
					'Groups Lists',
					'About us',
					'Coming Soon',
				),
			) );

			$this->delete_menu_items( 'Primary', array(
				untrailingslashit( home_url( '/members/elia/' ) ),
				untrailingslashit( home_url( '/groups/tatoo' ) ),
				'http://shop.gwangi-theme.com',
			), 'url' );

			$this->fix_menu_items_titles( 'Features - Homepage', array(
				'Talk to Real People'      => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-love-on"></i><span class="h5 d-block">Talk to Real People</span></span>',
				'Smooth & Simple Features' => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-smile"></i><span class="h5 d-block">Smooth & Simple Features</span></span>',
				'Your Data are Safe'       => '<span class="icon-wrapper"><i class="fa fa-lock"></i><span class="h5 d-block">Your Data are Safe</span></span>',
			) );

			$this->fix_menu_items_titles( 'Pre Footer 3', array(
				'https://www.instagram.com/' => '<i class="fa fa-instagram"></i> gwangi_community',
				'https://twitter.com/'       => '<i class="fa fa-twitter"></i> gwangi',
				'https://www.facebook.com/'  => '<i class="fa fa-facebook"></i> gwangi',
				'https://www.youtube.com/'   => '<i class="fa fa-youtube-play"></i> gwangi_tv',
				'https://www.snapchat.com/'  => '<i class="fa fa-snapchat-ghost"></i> gwangi_community',
			), 'url' );

			$this->fix_menu_items_titles( 'Social', array(
				'https://www.instagram.com/' => '<span class="icon-wrapper"><i class="fa fa-instagram"></i><span class="h5 d-block">@gwangi_community</span></span>',
				'https://twitter.com/'       => '<span class="icon-wrapper"><i class="fa fa-twitter"></i><span class="h5 d-block">@gwangi_community</span></span>',
				'https://www.facebook.com/'  => '<span class="icon-wrapper"><i class="fa fa-facebook"></i><span class="h5 d-block">@gwangi</span></span>',
				'https://www.youtube.com/'   => '<span class="icon-wrapper"><i class="fa fa-youtube-play"></i><span class="h5 d-block">@gwangi_tv</span></span>',
				'https://www.snapchat.com/'  => '<span class="icon-wrapper"><i class="fa fa-snapchat-ghost"></i><span class="h5 d-block">@gwangi_community</span></span>',
			), 'url' );

			$this->set_custom_logo( 'logo_community' );

			if ( class_exists( 'BuddyPress' ) ) {
				$this->enable_user_registrations();

				// Generate profile fields in the "Base" tab
				$this->generate_base_xprofile_fields();

				// Fix members directory search forms
				$directory_search_fields = array(
					'Name',
					'Passion',
					'Birthdate',
					'Gender',
					'Country',
					'City',
					'any',
				);
				$this->fix_bps_form( 'Search directory', $directory_search_fields, 'Members' );
				$this->fix_bps_form( 'Search Directory Sidebar Left', $directory_search_fields, 'Members Sidebar Left' );
				$this->fix_bps_form( 'Search Directory Sidebar Right', $directory_search_fields, 'Members Sidebar Right' );
				$this->fix_bps_form( 'Search home', array(
					'Name',
					'Birthdate',
					'Passion',
				), 'Members' );

				// Get ids of component pages (directories pages, register page, etc...)
				$directory_pages = bp_get_option( 'bp-pages' );

				// Adjust Cities menu items
				$cities_menu           = get_term_by( 'name', 'Cities', 'nav_menu' );
				$cities_menu_items     = wp_get_nav_menu_items( $cities_menu );
				$directory_search_form = get_page_by_title( 'Search directory', 'OBJECT', 'bps_form' );
				if ( ! empty( $directory_search_form ) ) {
					foreach ( $cities_menu_items as $menu_item ) {
						$menu_item->url = esc_url( add_query_arg( array(
							'field_' . xprofile_get_field_id_from_name( 'City' ) => urlencode( str_replace( ' ', '+', $menu_item->title ) ),
							'bps_form'                                           => $directory_search_form->ID,
						), get_permalink( $directory_pages['members'] ) ) );

						$this->update_menu_item( $cities_menu->term_id, $menu_item );
					}
				}
			}
		}

		/**
		 * After import logic for the Nightlife demo
		 */
		public function after_import_nightlife() {
			$this->convert_menu_items_relative_urls_to_absolute_urls();
			$this->delete_duplicate_pages();

			$this->assign_menus_to_locations( array(
				'primary'         => 'Primary',
				'user_logged_in'  => 'User - Logged In',
				'user_logged_out' => 'User - Logged Out',
			) );

			$this->fix_menu_items_hierarchy( 'Primary', array(
				'Home' => array(
					'Home 1',
					'Home 2',
				),
				'Community' => array(
					'menu image',
					'Members' => array(
						'Members Directory',
						'Swipe Members' => array(
							'All Members',
							'Only New York',
						),
					),
					'Groups' => array(
						'Groups Directory',
						'+Create Group',
					),
					'Others' => array(
						'Social Wall',
						'Forums',
						'Register',
						'Log In',
					),
				),
				'Events' => array(
					'All Events',
					'Venues',
					'Event Organizers',
				),
				'Pages' => array(
					'Members Lists',
					'Groups Lists',
					'About us',
					'Coming Soon',
				),
			) );

			$this->delete_menu_items( 'Primary', array(
				'http://shop.gwangi-theme.com',
			), 'url' );

			$this->fix_menu_items_titles( 'Features - Homepage', array(
				'Talk to Real People'      => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-love-on"></i><span class="h5 d-block">Talk to Real People</span></span>',
				'Smooth & Simple Features' => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-smile"></i><span class="h5 d-block">Smooth & Simple Features</span></span>',
				'Your Data are Safe'       => '<span class="icon-wrapper"><i class="fa fa-lock"></i><span class="h5 d-block">Your Data are Safe</span></span>',
			) );

			$this->fix_menu_items_titles( 'Pre Footer 3', array(
				'https://www.instagram.com/' => '<i class="fa fa-instagram"></i> gwangi_community',
				'https://twitter.com/'       => '<i class="fa fa-twitter"></i> gwangi',
				'https://www.facebook.com/'  => '<i class="fa fa-facebook"></i> gwangi',
				'https://www.youtube.com/'   => '<i class="fa fa-youtube-play"></i> gwangi_tv',
				'https://www.snapchat.com/'  => '<i class="fa fa-snapchat-ghost"></i> gwangi_community',
			), 'url' );

			$this->fix_menu_items_titles( 'Social', array(
				'https://www.instagram.com/' => '<span class="icon-wrapper"><i class="fa fa-instagram"></i><span class="h5 d-block">@gwangi_community</span></span>',
				'https://twitter.com/'       => '<span class="icon-wrapper"><i class="fa fa-twitter"></i><span class="h5 d-block">@gwangi_community</span></span>',
				'https://www.facebook.com/'  => '<span class="icon-wrapper"><i class="fa fa-facebook"></i><span class="h5 d-block">@gwangi</span></span>',
				'https://www.youtube.com/'   => '<span class="icon-wrapper"><i class="fa fa-youtube-play"></i><span class="h5 d-block">@gwangi_tv</span></span>',
				'https://www.snapchat.com/'  => '<span class="icon-wrapper"><i class="fa fa-snapchat-ghost"></i><span class="h5 d-block">@gwangi_community</span></span>',
			), 'url' );

			$this->set_custom_logo( 'logo-nightlife' );

			if ( class_exists( 'BuddyPress' ) ) {
				$this->enable_user_registrations();

				// Generate profile fields in the "Base" tab
				$this->generate_base_xprofile_fields();

				// Fix members directory search forms
				$directory_search_fields = array(
					'Name',
					'Passion',
					'Birthdate',
					'Gender',
					'Country',
					'City',
					'any',
				);
				$this->fix_bps_form( 'Search directory', $directory_search_fields, 'Members' );
				$this->fix_bps_form( 'Search Directory Sidebar Left', $directory_search_fields, 'Members Sidebar Left' );
				$this->fix_bps_form( 'Search Directory Sidebar Right', $directory_search_fields, 'Members Sidebar Right' );

				// Get ids of component pages (directories pages, register page, etc...)
				$directory_pages = bp_get_option( 'bp-pages' );

				// Adjust Cities menu items
				$cities_menu           = get_term_by( 'name', 'Cities', 'nav_menu' );
				$cities_menu_items     = wp_get_nav_menu_items( $cities_menu );
				$directory_search_form = get_page_by_title( 'Search directory', 'OBJECT', 'bps_form' );
				if ( ! empty( $directory_search_form ) ) {
					foreach ( $cities_menu_items as $menu_item ) {
						$menu_item->url = esc_url( add_query_arg( array(
							'field_' . xprofile_get_field_id_from_name( 'City' ) => urlencode( str_replace( ' ', '+', $menu_item->title ) ),
							'bps_form'                                           => $directory_search_form->ID,
						), get_permalink( $directory_pages['members'] ) ) );

						$this->update_menu_item( $cities_menu->term_id, $menu_item );
					}
				}
			}

			$this->update_tec_options( array(
				'postsPerPage'        => '9',
				'stylesheetOption'    => 'full',
				'tribeEventsTemplate' => 'template-classic-12-cols-left.php',
				'viewOption'          => 'list',
			) );
		}

		/**
		 * After import logic for the Learn demo
		 */
		public function after_import_learn() {
			$this->convert_menu_items_relative_urls_to_absolute_urls();
			$this->delete_duplicate_pages();

			$this->assign_menus_to_locations( array(
				'primary'         => 'Primary',
				'user_logged_in'  => 'User - Logged In',
				'user_logged_out' => 'User - Logged Out',
			) );

			$this->fix_menu_items_hierarchy( 'Primary', array(
				'Community' => array(
					'Learners' => array(
						'Learners Directory',
						'Swipe Members' => array(
							'All Members',
							'Only New York',
						),
					),
					'Groups' => array(
						'Groups Directory',
						'+Create Group',
					),
					'Others' => array(
						'Social Wall',
						'Forums',
						'Register',
						'Log In',
					),
				),
				'Learndash' => array(
					'Courses' => array(
						'Course example',
					),
					'Lessons',
					'Topics',
					'Quizzes',
					'Learndash Profile'
				),
				'Pages' => array(
					'Learners Lists',
					'Groups Lists',
					'Coming Soon',
				),
			) );

			$this->delete_menu_items( 'Primary', array(
				'http://shop.gwangi-theme.com',
			), 'url' );

			$this->fix_menu_items_titles( 'Features - Homepage', array(
				'Talk to Real People'      => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-love-on"></i><span class="h5 d-block">Talk to Real People</span></span>',
				'Smooth & Simple Features' => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-smile"></i><span class="h5 d-block">Smooth & Simple Features</span></span>',
				'Your Data are Safe'       => '<span class="icon-wrapper"><i class="fa fa-lock"></i><span class="h5 d-block">Your Data are Safe</span></span>',
			) );

			$this->fix_menu_items_titles( 'Pre Footer 3', array(
				'https://www.instagram.com/' => '<i class="fa fa-instagram"></i> gwangi_community',
				'https://twitter.com/'       => '<i class="fa fa-twitter"></i> gwangi',
				'https://www.facebook.com/'  => '<i class="fa fa-facebook"></i> gwangi',
				'https://www.youtube.com/'   => '<i class="fa fa-youtube-play"></i> gwangi_tv',
				'https://www.snapchat.com/'  => '<i class="fa fa-snapchat-ghost"></i> gwangi_community',
			), 'url' );

			$this->fix_menu_items_titles( 'Social', array(
				'https://www.instagram.com/' => '<span class="icon-wrapper"><i class="fa fa-instagram"></i><span class="h5 d-block">@gwangi_community</span></span>',
				'https://twitter.com/'       => '<span class="icon-wrapper"><i class="fa fa-twitter"></i><span class="h5 d-block">@gwangi_community</span></span>',
				'https://www.facebook.com/'  => '<span class="icon-wrapper"><i class="fa fa-facebook"></i><span class="h5 d-block">@gwangi</span></span>',
				'https://www.youtube.com/'   => '<span class="icon-wrapper"><i class="fa fa-youtube-play"></i><span class="h5 d-block">@gwangi_tv</span></span>',
				'https://www.snapchat.com/'  => '<span class="icon-wrapper"><i class="fa fa-snapchat-ghost"></i><span class="h5 d-block">@gwangi_community</span></span>',
			), 'url' );

			$this->set_custom_logo( 'logo-learn' );

			if ( class_exists( 'BuddyPress' ) ) {
				$this->enable_user_registrations();

				// Generate profile fields in the "Base" tab
				$this->generate_base_xprofile_fields();

				// Fix members directory search forms
				$directory_search_fields = array(
					'Name',
					'Passion',
					'Birthdate',
					'Gender',
					'Country',
					'City',
					'any',
				);
				$this->fix_bps_form( 'Search directory', $directory_search_fields, 'Learners' );
				$this->fix_bps_form( 'Search Directory Sidebar Left', $directory_search_fields, 'Members Sidebar Left' );
				$this->fix_bps_form( 'Search Directory Sidebar Right', $directory_search_fields, 'Members Sidebar Right' );

				// Get ids of component pages (directories pages, register page, etc...)
				$directory_pages = bp_get_option( 'bp-pages' );

				// Adjust Cities menu items
				$cities_menu           = get_term_by( 'name', 'Cities', 'nav_menu' );
				$cities_menu_items     = wp_get_nav_menu_items( $cities_menu );
				$directory_search_form = get_page_by_title( 'Search directory', 'OBJECT', 'bps_form' );
				if ( ! empty( $directory_search_form ) ) {
					foreach ( $cities_menu_items as $menu_item ) {
						$menu_item->url = esc_url( add_query_arg( array(
							'field_' . xprofile_get_field_id_from_name( 'City' ) => urlencode( str_replace( ' ', '+', $menu_item->title ) ),
							'bps_form'                                           => $directory_search_form->ID,
						), get_permalink( $directory_pages['members'] ) ) );

						$this->update_menu_item( $cities_menu->term_id, $menu_item );
					}
				}
			}

			// Change BuddyPress for LearnDash option
			$bp_lms_options = get_site_option( 'buddypress_learndash_plugin_options', array() );
			$bp_lms_options['courses_visibility'] = 'on';
			update_site_option( 'buddypress_learndash_plugin_options', $bp_lms_options );
		}

		/**
		 * After import logic for the Spiritual demo
		 */
		public function after_import_spiritual() {
			$this->convert_menu_items_relative_urls_to_absolute_urls();
			$this->delete_duplicate_pages();

			$this->assign_menus_to_locations( array(
				'primary'         => 'Primary',
				'user_logged_in'  => 'User - Logged In',
				'user_logged_out' => 'User - Logged Out',
			) );

			$this->fix_menu_items_hierarchy( 'Primary', array(
				'Home' => array(
					'Home 1',
					'Home 2',
				),
				'Community' => array(
					'menu image',
					'Members' => array(
						'Members Directory',
						'Swipe Members' => array(
							'All Members',
							'Only New York',
						),
					),
					'Groups' => array(
						'Groups Directory',
						'+Create Group',
					),
					'Others' => array(
						'Social Wall',
						'Forums',
						'Register',
						'Log In',
					),
				),
				'Pages' => array(
					'Members Lists',
					'Groups Lists',
					'About us',
					'Coming Soon',
				),
			) );

			$this->delete_menu_items( 'Primary', array(
				'http://shop.gwangi-theme.com',
			), 'url' );

			$this->fix_menu_items_titles( 'Features - Homepage', array(
				'Talk to Real People'      => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-love-on"></i><span class="h5 d-block">Talk to Real People</span></span>',
				'Smooth & Simple Features' => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-smile"></i><span class="h5 d-block">Smooth & Simple Features</span></span>',
				'Your Data are Safe'       => '<span class="icon-wrapper"><i class="fa fa-lock"></i><span class="h5 d-block">Your Data are Safe</span></span>',
			) );

			$this->fix_menu_items_titles( 'Pre Footer 3', array(
				'https://www.instagram.com/' => '<i class="fa fa-instagram"></i> gwangi_community',
				'https://twitter.com/'       => '<i class="fa fa-twitter"></i> gwangi',
				'https://www.facebook.com/'  => '<i class="fa fa-facebook"></i> gwangi',
				'https://www.youtube.com/'   => '<i class="fa fa-youtube-play"></i> gwangi_tv',
				'https://www.snapchat.com/'  => '<i class="fa fa-snapchat-ghost"></i> gwangi_community',
			), 'url' );

			$this->fix_menu_items_titles( 'Social', array(
				'https://www.instagram.com/' => '<span class="icon-wrapper"><i class="fa fa-instagram"></i><span class="h5 d-block">@gwangi_community</span></span>',
				'https://twitter.com/'       => '<span class="icon-wrapper"><i class="fa fa-twitter"></i><span class="h5 d-block">@gwangi_community</span></span>',
				'https://www.facebook.com/'  => '<span class="icon-wrapper"><i class="fa fa-facebook"></i><span class="h5 d-block">@gwangi</span></span>',
				'https://www.youtube.com/'   => '<span class="icon-wrapper"><i class="fa fa-youtube-play"></i><span class="h5 d-block">@gwangi_tv</span></span>',
				'https://www.snapchat.com/'  => '<span class="icon-wrapper"><i class="fa fa-snapchat-ghost"></i><span class="h5 d-block">@gwangi_community</span></span>',
			), 'url' );

			$this->set_custom_logo( 'logo-spiritual' );

			if ( class_exists( 'BuddyPress' ) ) {
				$this->enable_user_registrations();

				// Generate profile fields in the "Base" tab
				$this->generate_base_xprofile_fields();

				// Fix members directory search forms
				$directory_search_fields = array(
					'Name',
					'Passion',
					'Birthdate',
					'Gender',
					'Country',
					'City',
					'any',
				);
				$this->fix_bps_form( 'Search directory', $directory_search_fields, 'Members' );
				$this->fix_bps_form( 'Search Directory Sidebar Left', $directory_search_fields, 'Members Sidebar Left' );
				$this->fix_bps_form( 'Search Directory Sidebar Right', $directory_search_fields, 'Members Sidebar Right' );
				$this->fix_bps_form( 'Search home', array(
					'Name',
					'Birthdate',
					'Passion',
				), 'Members' );

				// Get ids of component pages (directories pages, register page, etc...)
				$directory_pages = bp_get_option( 'bp-pages' );

				// Adjust Cities menu items
				$cities_menu           = get_term_by( 'name', 'Cities', 'nav_menu' );
				$cities_menu_items     = wp_get_nav_menu_items( $cities_menu );
				$directory_search_form = get_page_by_title( 'Search directory', 'OBJECT', 'bps_form' );
				if ( ! empty( $directory_search_form ) ) {
					foreach ( $cities_menu_items as $menu_item ) {
						$menu_item->url = esc_url( add_query_arg( array(
							'field_' . xprofile_get_field_id_from_name( 'City' ) => urlencode( str_replace( ' ', '+', $menu_item->title ) ),
							'bps_form'                                           => $directory_search_form->ID,
						), get_permalink( $directory_pages['members'] ) ) );

						$this->update_menu_item( $cities_menu->term_id, $menu_item );
					}
				}
			}
		}

		/**
		 * After import logic for the Mentor demo
		 */
		public function after_import_mentor() {
			$this->convert_menu_items_relative_urls_to_absolute_urls();
			$this->delete_duplicate_pages();

			$this->assign_menus_to_locations( array(
				'primary'         => 'Primary',
				'user_logged_in'  => 'User - Logged In',
				'user_logged_out' => 'User - Logged Out',
			) );

			$this->fix_menu_items_hierarchy( 'Primary', array(
				'Community' => array(
					'Members Directory' => array(
						'All Members',
						'Swipe Members' => array(
							'All Members',
							'Only New York',
						),
					),
					'Groups Directory' => array(
						'All Groups',
						'+Create Group',
					),
					'Others' => array(
						'Top members',
						'Create user review',
						'Social Wall',
						'Forums',
						'Log In',
						'Register'
					),
				),
				'Pages' => array(
					'Members Lists',
					'Groups Lists',
					'Coming Soon',
				),
			) );

			$this->delete_menu_items( 'Primary', array(
				'http://shop.gwangi-theme.com',
			), 'url' );

			$this->fix_menu_items_titles( 'Features - Homepage', array(
				'Modern'      => '<span class="icon-wrapper"><i class="fa fa-rocket"></i><span class="h5 d-block">Modern</span></span>',
				'Centralized' => '<span class="icon-wrapper"><i class="fa fa-circle-o-notch"></i><span class="h5 d-block">Centralized</span></span>',
				'Scalable'    => '<span class="icon-wrapper"><i class="fa fa-signal"></i><span class="h5 d-block">Scalable</span></span>',
			) );

			$this->fix_menu_items_titles( 'Social', array(
				'https://www.instagram.com/' => '<i class="fa fa-instagram"></i>',
				'https://twitter.com/'       => '<i class="fa fa-twitter"></i>',
				'https://www.facebook.com/'  => '<i class="fa fa-facebook"></i>',
				'https://www.youtube.com/'   => '<i class="fa fa-youtube-play"></i>',
				'https://www.snapchat.com/'  => '<i class="fa fa-snapchat-ghost"></i>',
			), 'url' );

			$this->set_custom_logo( 'logo-mentor' );

			if ( class_exists( 'BuddyPress' ) ) {
				$this->enable_user_registrations();

				// Generate profile fields in the "Base" tab
				$this->generate_base_xprofile_fields();

				$this->generate_xprofile_field( array(
					'name'    => 'Education',
					'type'    => 'selectbox',
					'choices' => array(
						'High school',
						'2-year college',
						'University',
						'Post grad',
					)
				) );

				// Fix members directory search forms
				$directory_search_fields = array(
					'Name',
					'Passion',
					'Birthdate',
					'Gender',
					'Country',
					'City',
					'any',
				);
				$this->fix_bps_form( 'Search directory', $directory_search_fields, 'Members' );
				$this->fix_bps_form( 'Search Directory Sidebar Left', $directory_search_fields, 'Members Sidebar Left' );
				$this->fix_bps_form( 'Search Directory Sidebar Right', $directory_search_fields, 'Members Sidebar Right' );
				$this->fix_bps_form( 'Search home', array(
					'Name',
					'Passion',
					'Education',
					'Birthdate',
				), 'Members' );
			}
		}

		/**
		 * After import logic for the Youzify demo
		 */
		public function after_import_youzify() {
			$this->convert_menu_items_relative_urls_to_absolute_urls();
			$this->delete_duplicate_pages();

			$this->assign_menus_to_locations( array(
				'primary'         => 'Primary',
				'user_logged_in'  => 'User - Logged In',
				'user_logged_out' => 'User - Logged Out',
			) );

			$this->fix_menu_items_hierarchy( 'Primary', array(
				'Home' => array(
					'Home 1',
					'Home 2',
				),
				'Community' => array(
					'menu image',
					'Members' => array(
						'Members Directory',
						'Swipe Members' => array(
							'All Members',
							'Only New York',
						),
					),
					'Groups' => array(
						'Groups Directory',
						'+Create Group',
					),
					'Others' => array(
						'Social Wall',
						'Forums',
						'Register',
						'Log In',
					),
				),
				'Pages' => array(
					'Members Lists',
					'Groups Lists',
					'About us',
					'Coming Soon',
				),
			) );

			$this->delete_menu_items( 'Primary', array(
				'http://shop.gwangi-theme.com',
			), 'url' );

			$this->fix_menu_items_titles( 'Features - Homepage', array(
				'Talk to Real People'      => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-love-on"></i><span class="h5 d-block">Talk to Real People</span></span>',
				'Smooth & Simple Features' => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-smile"></i><span class="h5 d-block">Smooth & Simple Features</span></span>',
				'Your Data are Safe'       => '<span class="icon-wrapper"><i class="fa fa-lock"></i><span class="h5 d-block">Your Data are Safe</span></span>',
			) );

			$this->fix_menu_items_titles( 'Pre Footer 3', array(
				'https://www.instagram.com/' => '<i class="fa fa-instagram"></i> gwangi_community',
				'https://twitter.com/'       => '<i class="fa fa-twitter"></i> gwangi',
				'https://www.facebook.com/'  => '<i class="fa fa-facebook"></i> gwangi',
				'https://www.youtube.com/'   => '<i class="fa fa-youtube-play"></i> gwangi_tv',
				'https://www.snapchat.com/'  => '<i class="fa fa-snapchat-ghost"></i> gwangi_community',
			), 'url' );

			$this->set_custom_logo( 'logo' );

			if ( class_exists( 'BuddyPress' ) ) {
				$this->enable_user_registrations();

				// Generate profile fields in the "Base" tab
				$this->generate_base_xprofile_fields();

				// Fix members directory search forms
				$directory_search_fields = array(
					'Name',
					'Passion',
					'Birthdate',
					'Gender',
					'Country',
					'City',
					'any',
				);
				$this->fix_bps_form( 'Search directory', $directory_search_fields, 'Members' );

				// Get ids of component pages (directories pages, register page, etc...)
				$directory_pages = bp_get_option( 'bp-pages' );

				// Adjust Cities menu items
				$cities_menu           = get_term_by( 'name', 'Cities', 'nav_menu' );
				$cities_menu_items     = wp_get_nav_menu_items( $cities_menu );
				$directory_search_form = get_page_by_title( 'Search directory', 'OBJECT', 'bps_form' );
				if ( ! empty( $directory_search_form ) ) {
					foreach ( $cities_menu_items as $menu_item ) {
						$menu_item->url = esc_url( add_query_arg( array(
							'field_' . xprofile_get_field_id_from_name( 'City' ) => urlencode( str_replace( ' ', '+', $menu_item->title ) ),
							'bps_form'                                           => $directory_search_form->ID,
						), get_permalink( $directory_pages['members'] ) ) );

						$this->update_menu_item( $cities_menu->term_id, $menu_item );
					}
				}
			}
		}

		/**
		 * After import logic for the Dating demo
		 */
		public function after_import_dating() {
			$this->convert_menu_items_relative_urls_to_absolute_urls();
			$this->delete_duplicate_pages();

			$this->assign_menus_to_locations( array(
				'primary'         => 'Primary',
				'user_logged_in'  => 'User - Logged In',
				'user_logged_out' => 'User - Logged Out',
			) );

			$this->fix_menu_items_hierarchy( 'Primary', array(
				'Home' => array(
					'Home 1',
					'Home 2',
				),
				'Community' => array(
					'menu image',
					'Members' => array(
						'Members Directory',
						'Swipe Members' => array(
							'All Members',
							'Only Women',
							'Only Men',
							'Only Others',
							'Only New York',
						),
						'Member Profile',
					),
					'Groups' => array(
						'Groups Directory',
						'Group Profile',
						'+Create Group',
					),
					'Others' => array(
						'Social Wall',
						'Forums',
						'Register',
						'Log In',
					),
				),
				'Pages' => array(
					'Members Lists',
					'Groups Lists',
					'About us',
					'Testimonials',
					'Coming Soon',
				),
			) );

			$this->delete_menu_items( 'Primary', array(
				'http://shop.gwangi-theme.com',
			), 'url' );

			$this->fix_menu_items_titles( 'Features - Homepage', array(
				'Talk to Real People'      => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-love-on"></i><span class="h5 d-block">Talk to Real People</span></span>',
				'Smooth & Simple Features' => '<span class="icon-wrapper"><i class="gwangi-icon gwangi-smile"></i><span class="h5 d-block">Smooth & Simple Features</span></span>',
				'Your Data are Safe'       => '<span class="icon-wrapper"><i class="fa fa-lock"></i><span class="h5 d-block">Your Data are Safe</span></span>',
			) );

			$this->fix_menu_items_titles( 'Pre Footer 3', array(
				'https://www.instagram.com/' => '<i class="fa fa-instagram"></i> gwangi_community',
				'https://twitter.com/'       => '<i class="fa fa-twitter"></i> gwangi',
				'https://www.facebook.com/'  => '<i class="fa fa-facebook"></i> gwangi',
				'https://www.youtube.com/'   => '<i class="fa fa-youtube-play"></i> gwangi_tv',
				'https://www.snapchat.com/'  => '<i class="fa fa-snapchat-ghost"></i> gwangi_community',
			), 'url' );

			$this->set_custom_logo( 'logo-dating' );

			if ( class_exists( 'BuddyPress' ) ) {
				$this->enable_user_registrations();

				// Generate profile fields in the "Base" tab
				$this->generate_base_xprofile_fields();

				// Generate profile fields in the "Availability" tab
				$this->generate_availability_profile_fields();

				// Generate profile fields in the "Looks" tab
				$this->generate_looks_profile_fields();

				// Generate profile fields in the "Background" tab
				$this->generate_background_profile_fields();

				$this->fix_bps_form( 'Search directory', array(
					'any',
					'Connection',
					'Gender',
					'Looking for',
					'Birthdate',
					'Passion',
					'Main language',
					'Body type',
					'Pets',
				), 'Members' );

				$sidebar_directory_search_fields = array(
					'any',
					'Connection',
					'Gender',
					'Looking for',
					'Birthdate',
				);
				$this->fix_bps_form( 'Search Directory Sidebar Left', $sidebar_directory_search_fields, 'Members Sidebar Left' );
				$this->fix_bps_form( 'Search Directory Sidebar Right', $sidebar_directory_search_fields, 'Members Sidebar Right' );

				$this->fix_bps_form( 'Search home', array(
					'Connection',
					'Gender',
					'Birthdate',
				), 'Members' );

				// Get ids of component pages (directories pages, register page, etc...)
				$directory_pages = bp_get_option( 'bp-pages' );

				// Adjust Interests menu items
				$interests_menu        = get_term_by( 'name', 'Interests', 'nav_menu' );
				$interests_menu_items  = wp_get_nav_menu_items( $interests_menu );
				$directory_search_form = get_page_by_title( 'Search directory', 'OBJECT', 'bps_form' );
				if ( ! empty( $directory_search_form ) ) {
					foreach ( $interests_menu_items as $menu_item ) {
						switch ( $menu_item->title ) {
							case 'Long term dating':
								$menu_item->url = esc_url( add_query_arg( array(
									'field_' . xprofile_get_field_id_from_name( 'Connection' ) => 'Long-term+dating',
									'bps_form' => $directory_search_form->ID,
								), get_permalink( $directory_pages['members'] ) ) );
								break;
							case 'Sport addicts':
								$menu_item->url = esc_url( add_query_arg( array(
									'field_' . xprofile_get_field_id_from_name( 'Passion' ) => 'Sport',
									'bps_form' => $directory_search_form->ID,
								), get_permalink( $directory_pages['members'] ) ) );
								break;
							case 'Spanish speaking':
								$menu_item->url = esc_url( add_query_arg( array(
									'field_' . xprofile_get_field_id_from_name( 'Main language' ) => 'Spanish',
									'bps_form' => $directory_search_form->ID,
								), get_permalink( $directory_pages['members'] ) ) );
								break;
							case 'Cooking masters':
								$menu_item->url = esc_url( add_query_arg( array(
									'field_' . xprofile_get_field_id_from_name( 'Passion' ) => 'Cooking',
									'bps_form' => $directory_search_form->ID,
								), get_permalink( $directory_pages['members'] ) ) );
								break;
							case 'Cats lovers':
								$menu_item->url = esc_url( add_query_arg( array(
									'field_' . xprofile_get_field_id_from_name( 'Pets' ) => urlencode( 'Cat(s)' ),
									'bps_form' => $directory_search_form->ID,
								), get_permalink( $directory_pages['members'] ) ) );
								break;
						}

						$this->update_menu_item( $interests_menu->term_id, $menu_item );
					}
				}
			}
		}

		/**
		 * After import logic for the Shop demo
		 */
		public function after_import_shop() {
			$this->convert_menu_items_relative_urls_to_absolute_urls();
			$this->delete_duplicate_pages();

			$this->assign_menus_to_locations( array(
				'primary' => 'Primary',
			) );

			$this->fix_menu_items_hierarchy( 'Primary', array(
				'Shop' => array(
					'Decor',
					'Music',
				),
				'Pages' => array(
					'Cart',
					'Checkout',
					'My account',
				),
			) );

			$this->fix_menu_items_titles( 'Tertiary', array(
				'+32 0458 85 96 51'        => '<i class="fa fa-phone"></i> +32 0458 85 96 51',
				'07:00 - 20:30'            => '<i class="fa fa-clock-o"></i> 07:00 - 20:30',
				'support@gwangi-store.com' => '<i class="fa fa-envelope-o"></i> support@gwangi-store.com',
			) );

			$this->set_custom_logo( 'logo-store' );

			// Setup WooCommerce pages
			if ( class_exists( 'WooCommerce' ) ) {
				$this->assign_wc_pages();

				// Setup YITH Wishlist page
				if ( class_exists( 'YITH_WCWL' ) ) {
					$wishlist_page = get_page_by_title( 'My Wishlist' );
					update_option( 'yith_wcwl_wishlist_page_id', $wishlist_page->ID );
				}

				// Setup YITH Infnite Scroll
				if ( class_exists( 'YITH_INFS' ) ) {
					$yith_infs_options = get_option( YITH_INFS_OPTION_NAME );

					$yith_infs_options['yith-infs-navselector']     = 'nav.woocommerce-pagination';
					$yith_infs_options['yith-infs-nextselector']    = 'nav.woocommerce-pagination a.next';
					$yith_infs_options['yith-infs-itemselector']    = 'li.product';
					$yith_infs_options['yith-infs-contentselector'] = '#main';

					update_option( YITH_INFS_OPTION_NAME, $yith_infs_options );
				}
			}
		}

		/**
		 * Generate profile fields in the "Base" tab
		 */
		private function generate_base_xprofile_fields() {
			// Generate Birthdate field.
			$this->generate_xprofile_field( array(
				'name' => 'Birthdate',
				'type' => 'datebox',
			) );

			// Generate Gender field.
			$this->generate_xprofile_field( array(
				'name'     => 'Gender',
				'type'     => 'selectbox',
				'required' => true,
				'choices'  => array(
					'Male',
					'Female',
					'Other',
				),
			) );

			// Generate Country field.
			$this->generate_xprofile_field( array(
				'name'     => 'Country',
				'type'     => 'selectbox',
				'required' => true,
				'choices'  => $this->get_countries(),
			) );

			// Generate City field.
			$this->generate_xprofile_field( array(
				'name' =>'City',
			) );

			// Generate Passion field.
			$this->generate_xprofile_field( array(
				'name'    => 'Passion',
				'type'    => 'selectbox',
				'choices' => array(
					'Sport',
					'Travel',
					'Cooking',
					'Cinema',
					'Music',
					'Tatoo',
					'Books',
					'Gaming',
					'History',
				),
			) );
		}

		/**
		 * Generate profile fields in the "Availability" tab
		 */
		private function generate_availability_profile_fields() {
			$this->generate_xprofile_field_group( array(
				'id'   => 2,
				'name' => 'Availability',
			) );

			// Generate Connection field.
			$this->generate_xprofile_field( array(
				'name'        => 'Connection',
				'type'        => 'selectbox',
				'field_group' => 2,
				'required'    => true,
				'choices'     => array(
					'Long Term Dating',
					'Short Term Dating',
					'Hookups',
					'New Friends',
				),
				'description' => 'What kind of relationship are you looking for?',
			) );

			// Generate Looking for field
			$this->generate_xprofile_field( array(
				'name'        => 'Looking for',
				'type'        => 'selectbox',
				'field_group' => 2,
				'required'    => true,
				'choices'     => array(
					'Women',
					'Men',
					'Others',
				),
				'description' => 'What are you looking for?',
			) );

			// Generate Status field
			$this->generate_xprofile_field( array(
				'name'        => 'Status',
				'type'        => 'selectbox',
				'field_group' => 2,
				'required'    => true,
				'choices'     => array(
					'Single',
					'Not Single',
				),
			) );

			// Generate Kids field
			$this->generate_xprofile_field( array(
				'name'        => 'Kids',
				'type'        => 'selectbox',
				'field_group' => 2,
				'choices'     => array(
					'Wants kids',
					'Might want kids',
					"Doesn't want kids",
				),
			) );
		}

		/**
		 * Generate profile fields in the "Looks" tab
		 */
		private function generate_looks_profile_fields() {
			$this->generate_xprofile_field_group( array(
				'id'   => 3,
				'name' => 'Looks',
			) );

			// Generate Height field.
			$this->generate_xprofile_field( array(
				'name'        => 'Height',
				'type'        => 'number',
				'field_group' => 3,
				'description' => 'Enter your height in cm',
			) );

			// Generate Body type field
			$this->generate_xprofile_field( array(
				'name'        => 'Body type',
				'type'        => 'selectbox',
				'field_group' => 3,
				'choices'     => array(
					'Average',
					'Thin',
					'Fit',
					'Jacked',
					'Curvy',
					'Thin',
					'Full figured',
					'A little extra',
					'Overweight',
				),
			) );
		}

		/**
		 * Generate profile fields in the "Background" tab
		 */
		private function generate_background_profile_fields() {
			$this->generate_xprofile_field_group( array(
				'id'   => 4,
				'name' => 'Background',
			) );

			// Generate Main language field.
			$this->generate_xprofile_field( array(
				'name'        => 'Main language',
				'type'        => 'selectbox',
				'field_group' => 4,
				'choices'     => array(
					'English',
					'Spanish',
					'German',
					'French',
					'Chinese',
					'Hindi',
					'Arabic',
					'Portuguese',
					'Russian',
					'Japanese',
					'Korean',
				),
			) );

			// Generate Ethnicity field.
			$this->generate_xprofile_field( array(
				'name'        => 'Ethnicity',
				'type'        => 'checkbox',
				'field_group' => 4,
				'choices'     => array(
					'Asian',
					'Black',
					'Native American',
					'Hispanic / Latin',
					'Indian',
					'Middle Eastern',
					'Pacific Islander',
					'White',
					'Other',
				),
			) );

			// Generate Drinks field.
			$this->generate_xprofile_field( array(
				'name'        => 'Drinks',
				'type'        => 'selectbox',
				'field_group' => 4,
				'choices'     => array(
					'Never',
					'Sometimes',
					'Often',
				),
			) );

			// Generate Smokes field.
			$this->generate_xprofile_field( array(
				'name'        => 'Smokes',
				'type'        => 'selectbox',
				'field_group' => 4,
				'choices'     => array(
					'Never',
					'Sometimes',
					'Often',
				),
			) );

			// Generate Education field.
			$this->generate_xprofile_field( array(
				'name'        => 'Education',
				'type'        => 'selectbox',
				'field_group' => 4,
				'choices'     => array(
					'High school',
					'2-year college',
					'University',
					'Post grad',
				),
			) );

			// Generate Pets field.
			$this->generate_xprofile_field( array(
				'name'        => 'Pets',
				'type'        => 'checkbox',
				'field_group' => 4,
				'choices'     => array(
					'Cat(s)',
					'Dog(s)',
				),
			) );
		}

		/**
		 * Return an array of all countries
		 *
		 * @return array
		 */
		private function get_countries() {
			return array(
				'Afghanistan',
				'Albania',
				'Algeria',
				'Andorra',
				'Angola',
				'Antigua and Barbuda',
				'Argentina',
				'Armenia',
				'Australia',
				'Austria',
				'Azerbaijan',
				'Bahamas',
				'Bahrain',
				'Bangladesh',
				'Barbados',
				'Belarus',
				'Belgium',
				'Belize',
				'Benin',
				'Bhutan',
				'Bolivia',
				'Bosnia and Herzegovina',
				'Botswana',
				'Brazil',
				'Brunei',
				'Bulgaria',
				'Burkina Faso',
				'Burundi',
				'Cambodia',
				'Cameroon',
				'Canada',
				'Cape Verde',
				'Central African Republic',
				'Chad',
				'Chile',
				'China',
				'Colombi',
				'Comoros',
				'Congo (Brazzaville)',
				'Congo',
				'Costa Rica',
				'Cote d\'Ivoire',
				'Croatia',
				'Cuba',
				'Cyprus',
				'Czech Republic',
				'Denmark',
				'Djibouti',
				'Dominica',
				'Dominican Republic',
				'East Timor (Timor Timur)',
				'Ecuador',
				'Egypt',
				'El Salvador',
				'Equatorial Guinea',
				'Eritrea',
				'Estonia',
				'Ethiopia',
				'Fiji',
				'Finland',
				'France',
				'Gabon',
				'Gambia, The',
				'Georgia',
				'Germany',
				'Ghana',
				'Greece',
				'Grenada',
				'Guatemala',
				'Guinea',
				'Guinea-Bissau',
				'Guyana',
				'Haiti',
				'Honduras',
				'Hungary',
				'Iceland',
				'India',
				'Indonesia',
				'Iran',
				'Iraq',
				'Ireland',
				'Israel',
				'Italy',
				'Jamaica',
				'Japan',
				'Jordan',
				'Kazakhstan',
				'Kenya',
				'Kiribati',
				'Korea, North',
				'Korea, South',
				'Kuwait',
				'Kyrgyzstan',
				'Laos',
				'Latvia',
				'Lebanon',
				'Lesotho',
				'Liberia',
				'Libya',
				'Liechtenstein',
				'Lithuania',
				'Luxembourg',
				'Macedonia',
				'Madagascar',
				'Malawi',
				'Malaysia',
				'Maldives',
				'Mali',
				'Malta',
				'Marshall Islands',
				'Mauritania',
				'Mauritius',
				'Mexico',
				'Micronesia',
				'Moldova',
				'Monaco',
				'Mongolia',
				'Morocco',
				'Mozambique',
				'Myanmar',
				'Namibia',
				'Nauru',
				'Nepal',
				'Netherlands',
				'New Zealand',
				'Nicaragua',
				'Niger',
				'Nigeria',
				'Norway',
				'Oman',
				'Pakistan',
				'Palau',
				'Panama',
				'Papua New Guinea',
				'Paraguay',
				'Peru',
				'Philippines',
				'Poland',
				'Portugal',
				'Qatar',
				'Romania',
				'Russia',
				'Rwanda',
				'Saint Kitts and Nevis',
				'Saint Lucia',
				'Saint Vincent',
				'Samoa',
				'San Marino',
				'Sao Tome and Principe',
				'Saudi Arabia',
				'Senegal',
				'Serbia and Montenegro',
				'Seychelles',
				'Sierra Leone',
				'Singapore',
				'Slovakia',
				'Slovenia',
				'Solomon Islands',
				'Somalia',
				'South Africa',
				'Spain',
				'Sri Lanka',
				'Sudan',
				'Suriname',
				'Swaziland',
				'Sweden',
				'Switzerland',
				'Syria',
				'Taiwan',
				'Tajikistan',
				'Tanzania',
				'Thailand',
				'Togo',
				'Tonga',
				'Trinidad and Tobago',
				'Tunisia',
				'Turkey',
				'Turkmenistan',
				'Tuvalu',
				'Uganda',
				'Ukraine',
				'United Arab Emirates',
				'United Kingdom',
				'United States',
				'Uruguay',
				'Uzbekistan',
				'Vanuatu',
				'Vatican City',
				'Venezuela',
				'Vietnam',
				'Yemen',
				'Zambia',
				'Zimbabwe',
			);
		}
	}
endif;

return new Gwangi_Merlin();
